==> nextcloud-16.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/fi.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} on saatavilla. Tarjolla on lisätietoja päivittämisestä.",
    "Update notifications" : "Päivitysilmoitukset",
    "Channel updated" : "Päivityskanava päivitetty",
    "The update server could not be reached since %d days to check for new updates." : "Päivityspalvelinta ei ole tavoitettu %d päivään; uusia päivityksiä ei voida tarkistaa.",
    "Please check the Nextcloud and server log files for errors." : "Tarkista Nextcloud- ja palvelinlokitiedostot virheiden osalta.",
    "Update to %1$s is available." : "Kohteen %1$s päivitys on saatavilla.",
    "Update for %1$s to version %2$s is available." : "Kohteen %1$s päivitys versioon %2$s on saatavilla.",
    "Update for {app} to version %s is available." : "Sovelluksen {app} päivitys versioon %s on saatavilla.",
    "Update notification" : "Päivitysilmoitus",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Käyttämäsi versio ei ole enää tuettu. Varmista, että päivität tuettuun versioon mahdollisimman pian.",
    "View in store" : "Näytä kaupassa",
    "Apps with available updates" : "Sovellukset, joihin saatavilla päivityksiä",
    "Open updater" : "Avaa päivittäjä",
    "Download now" : "Lataa heti",
    "What's new?" : "Mitä uutta?",
    "The update check is not yet finished. Please refresh the page." : "Päivitystarkistus ei ole vielä valmis. Päivitä sivu.",
    "Your version is up to date." : "Versiosi on ajan tasalla.",
    "Update channel:" : "Päivityskanava:",
    "Notify members of the following groups about available updates:" : "Ilmoita seuraavien ryhmien jäsenille saatavilla olevista päivityksistä:",
    "Only notification for app updates are available." : "Sovelluspäivityksiin on saatavilla vain huomautuksia.",
    "The selected update channel does not support updates of the server." : "Valittu päivityskanava ei tue palvelimen päivityksiä.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Uusi versio on saatavilla: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Tarkistettu {lastCheckedDate}",
    "View changelog" : "Näytä muutosloki",
    "Stable" : "Vakaa",
    "Production" : "Tuotanto",
    "Beta" : "Beta",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Voit aina päivittää uudempaan versioon tai kokeellisen jakelukanavan versioon. Et voi kuitenkaan palata aiempaan, vakaan julkaisukanavan versioon.",
    "Could not start updater, please try the manual update" : "Ei voitu aloittaa päivitystä, kokeile päivittämistä manuaalisesti"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/updatenotification/l10n/fi.js <==
OC.L10N.register(
    "updatenotification",
    {
    "{version} is available. Get more information on how to update." : "{version} on saatavilla. Tarjolla on lisätietoja päivittämisestä.",
    "Channel updated" : "Päivityskanava päivitetty",
    "Update notifications" : "Päivitysilmoitukset",
    "The update server could not be reached since %d days to check for new updates." : "Päivityspalvelinta ei ole tavoitettu %d päivään; uusia päivityksiä ei voida tarkistaa.",
    "Please check the Nextcloud and server log files for errors." : "Tarkista Nextcloud- ja palvelinlokitiedostot virheiden osalta.",
    "Update to %1$s is available." : "Kohteen %1$s päivitys on saatavilla.",
    "Update for %1$s to version %2$s is available." : "Kohteen %1$s päivitys versioon %2$s on saatavilla.",
    "Update for {app} to version %s is available." : "Sovelluksen {app} päivitys versioon %s on saatavilla.",
    "Update notification" : "Päivitysilmoitus",
    "The version you are running is not maintained anymore. Please make sure to update to a supported version as soon as possible." : "Käyttämäsi versio ei ole enää tuettu. Varmista, että päivität tuettuun versioon mahdollisimman pian.",
    "View in store" : "Näytä kaupassa",
    "Apps with available updates" : "Sovellukset, joihin saatavilla päivityksiä",
    "Open updater" : "Avaa päivittäjä",
    "Download now" : "Lataa heti",
    "What's new?" : "Mitä uutta?",
    "The update check is not yet finished. Please refresh the page." : "Päivitystarkistus ei ole vielä valmis. Päivitä sivu.",
    "Your version is up to date." : "Versiosi on ajan tasalla.",
    "Update channel:" : "Päivityskanava:",
    "Notify members of the following groups about available updates:" : "Ilmoita seuraavien ryhmien jäsenille saatavilla olevista päivityksistä:",
    "Only notification for app updates are available." : "Sovelluspäivityksiin on saatavilla vain huomautuksia.",
    "The selected update channel does not support updates of the server." : "Valittu päivityskanava ei tue palvelimen päivityksiä.",
    "A new version is available: <strong>{newVersionString}</strong>" : "Uusi versio on saatavilla: <strong>{newVersionString}</strong>",
    "Checked on {lastCheckedDate}" : "Tarkistettu {lastCheckedDate}",
    "View changelog" : "Näytä muutosloki",
    "Stable" : "Vakaa",
    "Beta" : "Beta",
    "You can always update to a newer version / experimental channel. But you can never downgrade to a more stable channel." : "Voit aina päivittää uudempaan versioon tai kokeellisen jakelukanavan versioon. Et voi kuitenkaan palata aiempaan, vakaan julkaisukanavan versioon.",
    "Could not start updater, please try the manual update" : "Ei voitu aloittaa päivitystä, kokeile päivittämistä manuaalisesti",
    "Production" : "Tuotanto"
},
"nplurals=2; plural=(n != 1);");
